@@ -3,6 +3,7 @@ import dash
 import pandas as pd
 from webviz_config.common_cache import CACHE
 from webviz_config.themes import default_theme
+from webviz_config import WebvizSettings
 
 # pylint: disable=no-name-in-module
 from webviz_config.plugins import (
@@ -22,16 +23,15 @@ def test_parameter_corr(dash_duo: dash.testing.composite.DashComposite) -> None:
     app.scripts.config.serve_locally = True
     app.config.suppress_callback_exceptions = True
     CACHE.init_app(app.server)
-    app.webviz_settings = {
-        "shared_settings": {"scratch_ensembles": {"iter-0": ""}},
-        "theme": default_theme,
-    }
+    webviz_settings = WebvizSettings(
+        shared_settings={"scratch_ensembles": {"iter-0": ""}}, theme=default_theme
+    )
     ensembles = ["iter-0"]
 
     with mock.patch(GET_PARAMETERS) as mock_parameters:
         mock_parameters.return_value = pd.read_csv("tests/data/parameters.csv")
 
-        parameter_correlation = ParameterCorrelation(app, ensembles)
+        parameter_correlation = ParameterCorrelation(app, webviz_settings, ensembles)
 
         app.layout = parameter_correlation.layout
         dash_duo.start_server(app)
