@@ -1,19 +1,18 @@
+from typing import Dict
 import os
 
 import pandas as pd
-import fmu.ensemble
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 
-
-@CACHE.memoize(timeout=CACHE.TIMEOUT)
-def scratch_ensemble(ensemble_name, ensemble_path):
-    return fmu.ensemble.ScratchEnsemble(ensemble_name, ensemble_path)
+from .fmu_input import scratch_ensemble
 
 
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
 @webvizstore
-def extract_volumes(ensemble_paths, volfolder, volfiles) -> pd.DataFrame:
+def extract_volumes(
+    ensemble_paths: dict, volfolder: str, volfiles: Dict[str, str]
+) -> pd.DataFrame:
     """Aggregates volumetric files from an FMU ensemble.
     Files must be stored on standardized csv format.
     """
